@@ -8,7 +8,9 @@ from django.template.response import TemplateResponse
 from django.template.defaultfilters import slugify
 from django.contrib.auth.decorators import user_passes_test
 from django.contrib.auth import authenticate, login, logout
-from django.core.files import File
+from django.core.files.storage import FileSystemStorage
+from django.core.files.images import ImageFile
+
 import simplejson as json
 
 from sorl.thumbnail import get_thumbnail
@@ -271,15 +273,16 @@ def product(request, product=None):
 def xhr_upload_photo(request):
     """Upload photos from form, return filenames and urls and thumbnails."""
     def handle_uploaded_image(orig_filename, f):
-        path, _, filename = random_filename(settings.MEDIA_PATH['product'],
-            ext=orig_filename.split('.')[-1])
-        destination = open(path, 'wb+')
-        for chunk in f.chunks():
-            destination.write(chunk)
-        destination.close()
+        folder = settings.MEDIA_PATH['product']
+        f = ImageFile(f)
+        fs = FileSystemStorage(
+            location=settings.MEDIA_ROOT + folder
+        )
+        filename = fs.save(orig_filename, f)
         return {
-            'path': path,
-            'filename': filename
+            'filename': '{}{}'.format(folder, filename),
+            'url': '{}{}{}'.format(settings.MEDIA_URL, folder,
+                filename),
         }
 
     if request.method != 'POST':
@@ -294,8 +297,6 @@ def xhr_upload_photo(request):
     for image in images:
         image['thumb'] = get_thumbnail(image['filename'], '200x150',
             crop='center').url
-        image['url'] = settings.MEDIA_URL + image['filename']
-        del image['path']
 
     response = {
         'images': images
@@ -305,10 +306,7 @@ def xhr_upload_photo(request):
 
 @user_passes_test(lambda u: u.is_staff)
 def xhr_update_photos(request):
-    try:
-        product = Product.objects.get(pk=request.POST['pk'])
-    except Product.DoesNotExist:
-        raise Http404
+    product = get_object_or_404(Product, pk=request.POST.get('pk', False))
 
     i = 1
     images = json.loads(request.POST['images'])
